about summary refs log tree commit diff
path: root/src/test/compile-fail/kindck-send-object.rs
diff options
context:
space:
mode:
authorHuon Wilson <dbau.pp+github@gmail.com>2015-02-17 23:48:32 +1100
committerHuon Wilson <dbau.pp+github@gmail.com>2015-02-18 11:27:51 +1100
commit7a14f4994eb4527a38d02c61fa83822df02f7b5d (patch)
treed9d3698e9f2897195403fdf196d05b633bd4f581 /src/test/compile-fail/kindck-send-object.rs
parentadfcd93f0c3b624399934558f63d945b7b6b663a (diff)
downloadrust-7a14f4994eb4527a38d02c61fa83822df02f7b5d.tar.gz
rust-7a14f4994eb4527a38d02c61fa83822df02f7b5d.zip
Update tests for the Send - 'static change.
Diffstat (limited to 'src/test/compile-fail/kindck-send-object.rs')
-rw-r--r--src/test/compile-fail/kindck-send-object.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/compile-fail/kindck-send-object.rs b/src/test/compile-fail/kindck-send-object.rs
index 7984b3b32c2..570f7ad7fe3 100644
--- a/src/test/compile-fail/kindck-send-object.rs
+++ b/src/test/compile-fail/kindck-send-object.rs
@@ -20,7 +20,7 @@ trait Message : Send { }
 
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
     //~^ ERROR the trait `core::marker::Send` is not implemented
 }
 
 fn box_object_with_no_bound_not_ok<'a>() {
@@ -28,7 +28,7 @@ fn box_object_with_no_bound_not_ok<'a>() {
 }
 
 fn object_with_send_bound_ok() {
-    assert_send::<&'static (Dummy+Send)>();
+    assert_send::<&'static (Dummy+Sync)>();
     assert_send::<Box<Dummy+Send>>();
 }
@@ -20,7 +20,7 @@ trait Message : Send { }
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
-    //~^ ERROR the trait `core::marker::Send` is not implemented
+    //~^ ERROR the trait `core::marker::Sync` is not implemented
 }
 